Enumeration
KompassExclusivity
Members
-
KOMPASS_EXCLUSIVITY_NORMAL -
No description available.
- Value:
0 - Available since: 0.1
- Value:
-
KOMPASS_EXCLUSIVITY_EXCLUSIVE -
Request the compositor to allocate space for this window.
- Value:
1 - Available since: 0.1
- Value:
-
KOMPASS_EXCLUSIVITY_IGNORE -
Request the compositor to stack layers on top of each other.
- Value:
2 - Available since: 0.1
- Value: