Enumeration
KompassPopupNotificationTimeoutBehaviour
Members
-
KOMPASS_POPUP_NOTIFICATION_TIMEOUT_BEHAVIOUR_DEFAULT -
Use the timeout set by the notification if set, otherwise use the value of the timeout property.
- Value:
0 - Available since: 0.1
- Value:
-
KOMPASS_POPUP_NOTIFICATION_TIMEOUT_BEHAVIOUR_FORCE -
Always use the value of the timeout property, ignore the timeout set by the notification.
- Value:
1 - Available since: 0.1
- Value:
-
KOMPASS_POPUP_NOTIFICATION_TIMEOUT_BEHAVIOUR_MIN -
Use the timeout set by the notification if set or the value of the timeout property, whichever value is higher.
- Value:
2 - Available since: 0.1
- Value:
-
KOMPASS_POPUP_NOTIFICATION_TIMEOUT_BEHAVIOUR_MAX -
Use the timeout set by the notification if set or the value of the timeout property, whichever value is lower.
- Value:
3 - Available since: 0.1
- Value: